@@ -150,7 +150,7 @@ public class JdbcTypeSG extends TypeSGChainImpl {
         pMethod.addLine(pStmt, ".setString(", pParamNum, ", ", pValue, ");");
       } else if (Column.Type.DATE.equals(type)) {
         pMethod.addLine(pStmt, ".setDate(", pParamNum, ", new ", java.sql.Date.class,
-                        "(", pValue, ".getTimeInMillis()));");
+                        "(", pValue, ".getTime().getTime()));");
       } else if (Column.Type.DOUBLE.equals(type)) {
         pMethod.addLine(pStmt, ".setDouble(", pParamNum, ", ", pValue, ".doubleValue());");
       } else if (Column.Type.FLOAT.equals(type)) {
@@ -161,10 +161,10 @@ public class JdbcTypeSG extends TypeSGChainImpl {
         pMethod.addLine(pStmt, ".setShort(", pParamNum, ", ", pValue, ".shortValue());");
       } else if (Column.Type.TIME.equals(type)) {
         pMethod.addLine(pStmt, ".setTime(", pParamNum, ", new ", java.sql.Date.class,
-                        "(", pValue, ".getTimeInMillis()));");
+                        "(", pValue, ".getTime().getTime()));");
       } else if (Column.Type.TIMESTAMP.equals(type)) {
         pMethod.addLine(pStmt, ".setTimestamp(", pParamNum, ", new ", Timestamp.class,
-                        "(", pValue, ".getTimeInMillis()));");
+                        "(", pValue, ".getTime().getTime()));");
       } else if (Column.Type.TINYINT.equals(type)) {
         pMethod.addLine(pStmt, ".setByte(", pParamNum, ", ", pValue, ".byteValue());");
       } else {
